/**
 * LightPreviewBase is not meant to be used directly, rather its the base implementation of
 *   previewing. It comes without a highlight theme or a highlighter. Go to LightPreview for how to
 *   implement your own theme and highlighter.
 * @customElement
 * @tagname light-preview-base
 *
 * @csspart base - The base wrapping element
 * @csspart preview - The wrapper around the iframe / div preview showing your code being run in the browser.
 * @csspart start-panel - The iframe or preview-div
 * @csspart preview-div - used for inline previews
 * @csspart iframe - used for iframe based previews (default)
 * @csspart panel-resizer - The button that resizes the panel
 * @csspart end-panel - The white space when dragging the resizer
 * @csspart source-details - The details element that shows the source code
 * @csspart code-wrapper - The div that wraps the <pre> + <code> elements containing your highlighted code
 * @csspart pre - The <pre> element wrapping the source code
 * @csspart code - The <code>  element wrapping the source code
 * @csspart actions - The buttons at the bottom of the code previewer
 * @csspart source-code-toggle - The button to show the source code
 * @csspart source-code-toggle-icon - The caret icon in the source code toggle
 *
 * @slot resize-icon - The icon to display in the resizer button. Override this to provide your own icon.
 * @slot summary - What to display in source code expander
 * @slot source-code-toggle-icon - Slot in your own icon to override the default caret.
 * @slot actions - Slot in buttons / links to allow for additional actions in the bottom bar.
 * @slot preview-code - If you want to run code that is slightly different from the source code you want to display, slot it into "preview-code"
 * @slot code - Used to display both source code and to power your preview in the iframe. If you slot in "preview-code", then it will only be used to show / highlight your source code.
 */
export default class LightPreviewBase extends BaseElement {
    /**
     * @override
     */
    static override dependencies: {
        "light-disclosure": typeof LightDisclosure;
    };
    /**
     * @override
     */
    static override styles: import("lit").CSSResult[];
    /**
     * @override
     */
    static override properties: {
        summary: {};
        sandboxSettings: {
            reflect: boolean;
            attribute: string;
        };
        previewMode: {
            reflect: boolean;
            attribute: string;
        };
        disableHighlight: {
            type: BooleanConstructor;
            attribute: string;
        };
        open: {
            reflect: boolean;
            type: BooleanConstructor;
        };
        resizePosition: {
            reflect: boolean;
            type: NumberConstructor;
            attribute: string;
        };
        resizing: {
            reflect: boolean;
            type: BooleanConstructor;
        };
        language: {};
        code: {
            attribute: boolean;
        };
        previewCode: {
            attribute: boolean;
        };
    };
    /**
     * The sandbox settings to provide to the <iframe>
     * @type {string}
     */
    sandboxSettings: string;
    /**
     * The text to provide in the <details> toggle button
     * @type {string}
     */
    summary: string;
    /**
     * The language to highlight for.
     * @type {string}
     */
    language: string;
    /**
     * Set to true to not use an <iframe> for previewing
     * @type {"iframe" | "shadow-dom"}
     */
    previewMode: "iframe" | "shadow-dom";
    /**
     * When the resizer is being dragged, this will be true.
     * @type {boolean}
     */
    resizing: boolean;
    /**
     * If disabled, its on you to provide `<pre><code></code></pre>`
     * @type {boolean}
     */
    disableHighlight: boolean;
    /**
     * We will take the code, wrap it in `<pre><code></code></pre>` and run it through
     * Highlight.js.
     * If the element has `disableHighlight`, we will not touch their code. Instead they must pass in escapedHTML.
     * @type {string}
     */
    code: string;
    /**
     * If `disableHighlight` is true, then you must pass in an element into `previewCode` to be able to get
     *   the code to run in the previewer.
     * @type {string}
     */
    previewCode: string;
    /**
     * Whether or not the source code is being shown
     * @type {boolean}
     */
    open: boolean;
    /**
     * The current position of the resizer. 100 means all the way to right. 0 means all the way to left.
     * @type {number}
     */
    resizePosition: number;
    /**
     * @internal
     * @type {ResizeObserver}
     */
    resizeObserver: ResizeObserver;
    /**
     * @internal
     * @type {MutationObserverInit}
     */
    __mutationObserverConfig: MutationObserverInit;
    /**
     * @internal
     * @type {() => void}
     */
    previewCodeDebounce: () => void;
    /**
     * @internal
     * @type {() => void}
     */
    codeDebounce: () => void;
    /**
     * @property
     * @type {"soft" | "hard"}
     * If `wrap="soft"`, lines will wrap when they reach the edge of their container. If `wrap="none"`, lines will not wrap instead all the user to scroll horizontally to see more code.
     */
    wrap: "soft" | "hard";
    /**
     * @internal
     * Reinstalls the mutation on slotted preview-code
     */
    resetIframeCodeMutationObserver(): void;
    previewCodeMutationObserver: MutationObserver | undefined;
    /**
     * @internal
     * Reinstalls the mutation observer on slotted code
     */
    resetCodeMutationObserver(): void;
    codeMutationObserver: MutationObserver | undefined;
    /**
     * @internal
     * @param {"preview-code" | "code"} variable
     */
    handleMutation(variable: "preview-code" | "code"): void;
    /**
     * @internal
     * @param {string} name
     * @returns {HTMLSlotElement | null | undefined}
     */
    findSlot(name: string): HTMLSlotElement | null | undefined;
    /**
     * @internal
     * @param {Event | { target?: undefined | null | HTMLSlotElement }} e
     */
    handleTemplate(e: Event | {
        target?: undefined | null | HTMLSlotElement;
    }): void;
    /**
     * @internal
     */
    updateIframeContent(): void;
    /**
     * @internal
     * @param {string} text
     */
    escapeCharacters(text: string): string;
    /**
     * Only used to unescape things like `&lt;/script>` from slotted content.
     * @internal
     * @param {string} text
     */
    unescapeTags(text: string): string;
    /**
     * @override
     * @internal
     * @param {import("lit").PropertyValues<this>} changedProperties
     */
    override willUpdate(changedProperties: import("lit").PropertyValues<this>): void;
    _iframeDebounce: NodeJS.Timeout | undefined;
    /**
     * @internal
     * Sets an initial width so we dont need to keep computing getBoundingClientRect
     */
    updateCachedWidth(): void;
    cachedWidth: number | undefined;
    /**
     * @internal
     * @param {ResizeObserverEntry[]} entries
     */
    handleResize(entries: ResizeObserverEntry[]): void;
    /**
     * @public
     * Override this function to use your own highlighter
     */
    public highlight(code?: string): string;
    /**
     * @private
     * @param {HTMLElement | Element | ShadowRoot} root
     */
    private addShadowRootToPreview;
    /**
     * @override
     */
    override render(): import("lit").TemplateResult<1>;
    /**
     * @internal
     */
    get panelResizer(): Element | null | undefined;
    /** Drag stuff */
    /**
     * @internal
     * @param {PointerEvent} event
     */
    handleDrag(event: PointerEvent): void;
    /**
     * @internal
     */
    updateResizePosition(resizePosition?: number): void;
    /**
     * @internal
     * @param {KeyboardEvent} event
     */
    handleResizerKeydown(event: KeyboardEvent): void;
    /**
     * @internal
     * @param {number} pixels
     * @return {number}
     */
    pixelsToPercentage(pixels: number): number;
}
import { BaseElement } from "../internal/base-element.js";
import { LightDisclosure } from "./light-disclosure.js";
